<?php
/**
 * Plugin Name: Projectify
 * Plugin URI:  www.persianscript.ir
 * Description: Brand new addon for Elementor Page builder. It provides the set of modules to create different kinds of content, adds custom modules to your website and applies attractive styles in the matter of several clicks!
 * Version:     2.4
 * Author:      پرشین اسکریپت
 * Author URI:  www.persianscript.ir
 * Text Domain: projectify
 * License:     GPL-2.0+
 * License URI: www.persianscript.ir
 * Domain Path: /languages
 */

// Exit if accessed directly. 
if ( ! defined( 'ABSPATH' ) ) { exit; }

define ( 'PROJECTIFY_VERSION', '2.4');	// since v2.1


if ( ! class_exists( 'Projectify_Core' ) ) 
{
	
	class Projectify_Core {
		
		// ---------------------------------------------------------
		// VARIABLES
		// ---------------------------------------------------------
		private static $instance = null;
		
		public $version = '1.0';
		
		private $plugin_path = null;
		
		
		// ---------------------------------------------------------
		// FUNCTIONS
		// ---------------------------------------------------------
		
		// Disable class cloning
		public function __clone() 
		{

			// Cloning instances of the class is forbidden
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'projectify' ));

		}
		
		
		// Disable unserializing the class.
		public function __wakeup() 
		{

			// Unserializing instances of the class is forbidden.
			_doing_it_wrong( __FUNCTION__, esc_html__( 'Cheatin&#8217; huh?', 'projectify' ));

		}
		
		
		public function __construct() 
		{
			
			$this->includes();
			$this->init_hooks();
			
			
			define ('PROJECTIFY_PLUGIN_URL', plugin_dir_url(__FILE__));
		
		}
		
		
		// Includes
		public function includes() 
		{

			require_once( __DIR__ . '/projectify-plugin.php' );
			require_once( __DIR__ . '/includes/projectify-helper.php' );
		}
		
		
		// Hook into actions and filters.
		private function init_hooks() 
		{

			add_action( 'init', [ $this, 'translation' ] );
			add_action( 'plugins_loaded', [ $this, 'init' ] );

		}
		
		
		// Check if elementor exists
		public function init() 
		{
			
			// Check if Elementor installed and actived
			if ( ! did_action( 'elementor/loaded' ) ) {
				add_action( 'admin_notices', [ $this, 'admin_notice_missing_main_plugin' ] );
				return;
			}
			
			// Projectify Classes
			new \Projectify\Projectify_Plugin();
		}
		
		
		// Warning when the site doesn't have Elementor installed or activated.
		public function admin_notice_missing_main_plugin() 
		{
			$message = sprintf(
				/* translators: 1: Projectify 2: Elementor */
				esc_html__( '"%1$s" requires "%2$s" to be installed and activated.', 'projectify' ),
				'<strong>' . esc_html__( 'Projectify', 'projectify' ) . '</strong>',
				'<strong>' . esc_html__( 'Elementor', 'projectify' ) . '</strong>'
			);
			printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

		}

		
		// Load text domain
		public function translation() 
		{
			load_plugin_textdomain( 'projectify', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
		}
		
		
		
		
		
		// Returns the instance.
		public static function get_instance() 
		{
			// If the single instance hasn't been set, set it now.
			if ( null == self::$instance ) {
				self::$instance = new self;
			}
			return self::$instance;
		}
		
	}
	
}


if ( ! function_exists( 'projectify_load' ) ) 
{
	// Returns instanse of the plugin class.
	function Projectify_load() 
	{
		return projectify_Core::get_instance();
	}
	
	projectify_load();
}

